@@ -6,17 +6,10 @@
 #' around \code{\link[survey]{svydesign}}. All survey variables must be included
 #' in the data.frame itself. Variables are selected by using bare column names, or
 #' convenience functions described in \code{\link[dplyr]{select}}.
-#' \code{as_survey_design_} is the standard evaluation counterpart to
-#' \code{as_survey_design}.
 #'
 #' If provided a \code{survey.design2} object from the survey package,
 #' it will turn it into a srvyr object, so that srvyr functions will work with it
 #'
-#' There is also limited and experimental support for databases using dplyr's \code{tbl_sql}
-#' objects. Not all operations are available for these objects. See
-#' \code{vignette("databases", package = "dplyr")} for more information on setting
-#' up databases in dplyr.
-#'
 #' @export
 #' @param .data A data frame (which contains the variables specified below)
 #' @param ids Variables specifying cluster ids from largest level to smallest level
@@ -35,8 +28,6 @@
 #' approximation. An object of class ppsmat to use the Horvitz-Thompson estimator.
 #' @param variance For pps without replacement, use variance="YG" for the Yates-Grundy estimator
 #' instead of the Horvitz-Thompson estimator
-#' @param uid Required for databases only, variables that uniquely identify the
-#' observations of your survey.
 #' @param ... ignored
 #' @return An object of class \code{tbl_svy}
 #' @examples
@@ -76,11 +67,12 @@
 #' dpps <- election_pps %>%
 #'   as_survey_design(fpc = p, pps = "brewer")
 #'
-#' ## as_survey_design_ uses standard evaluation
-#' strata_var <- "stype"
-#' weights_var <- "pw"
-#' dstrata2 <- apistrat %>%
-#'   as_survey_design_(strata = strata_var, weights = weights_var)
+#' # dplyr 0.7 introduced new style of NSE called quosures
+#' # See `vignette("programming", package = "dplyr")` for details
+#' st <- quo(stype)
+#' wt <- quo(pw)
+#' dstrata <- apistrat %>%
+#'   as_survey_design(strata = !!st, weights = !!wt)
 #'
 as_survey_design <- function(.data, ...) {
   UseMethod("as_survey_design")
@@ -92,74 +84,88 @@ as_survey_design.data.frame <-
   function(.data, ids = NULL, probs = NULL, strata = NULL,
            variables = NULL, fpc = NULL, nest = FALSE,
            check_strata = !nest, weights = NULL, pps = FALSE,
-           variance = c("HT", "YG"), uid = NULL, ...) {
+           variance = c("HT", "YG"), ...) {
 
-  if (!missing(ids)) {
-    ids <- lazy_parent(ids)
-    ids <- if (ids$expr == 1 || ids$expr == 0) NULL else helper(ids, .data)
-  }
-  if (!missing(probs)) probs <- helper(lazy_parent(probs), .data)
-  if (!missing(strata)) strata <- helper(lazy_parent(strata), .data)
-  if (!missing(fpc)) fpc <- helper(lazy_parent(fpc), .data)
-  if (!missing(weights)) weights <- helper(lazy_parent(weights), .data)
-  if (!missing(variables)) variables <- helper(lazy_parent(variables), .data)
-  if (!missing(uid)) uid <- helper(lazy_parent(uid), .data)
+  ids <- srvyr_select_vars(rlang::enquo(ids), .data, check_ids = TRUE)
+  probs <- srvyr_select_vars(rlang::enquo(probs), .data)
+  strata <- srvyr_select_vars(rlang::enquo(strata), .data)
+  fpc <- srvyr_select_vars(rlang::enquo(fpc), .data)
+  weights <- srvyr_select_vars(rlang::enquo(weights), .data)
+  variables <- srvyr_select_vars(rlang::enquo(variables), .data)
 
-  as_survey_design_(.data, ids, probs = probs, strata = strata,
-                    variables = variables, fpc = fpc, nest = nest,
-                    check_strata = check_strata, weights = weights, pps = pps,
-                    variance = variance, uid = uid)
+  if (is.null(ids)) ids <- ~1
+  out <- survey::svydesign(
+    ids, probs, strata, variables, fpc, .data, nest, check_strata, weights, pps
+  )
+
+  as_tbl_svy(
+    out,
+    list(ids = ids, probs = probs, strata = strata, fpc = fpc, weights = weights)
+  )
 }
 
-#' @export
-#' @rdname as_survey_design
-as_survey_design.tbl_sql <- as_survey_design.data.frame
-
 #' @export
 #' @rdname as_survey_design
 as_survey_design.survey.design2 <- function(.data, ...) {
   as_tbl_svy(.data)
 }
 
-
 #' @export
 #' @rdname as_survey_design
+as_survey_design.tbl_lazy <-
+  function(.data, ids = NULL, probs = NULL, strata = NULL,
+           variables = NULL, fpc = NULL, nest = FALSE,
+           check_strata = !nest, weights = NULL, pps = FALSE,
+           variance = c("HT", "YG"), ...) {
+
+    ids <- rlang::enquo(ids)
+    probs <- rlang::enquo(probs)
+    strata <- rlang::enquo(strata)
+    fpc <- rlang::enquo(fpc)
+    weights <- rlang::enquo(weights)
+    variables <- rlang::enquo(variables)
+
+    survey_vars_local <- get_lazy_vars(
+      data = .data, id = !!ids, !!probs, !!strata, !!fpc, !!weights, !!variables
+    )
+
+    ids <- srvyr_select_vars(ids, survey_vars_local, check_ids = TRUE)
+    probs <- srvyr_select_vars(probs, survey_vars_local)
+    strata <- srvyr_select_vars(strata, survey_vars_local)
+    fpc <- srvyr_select_vars(fpc, survey_vars_local)
+    weights <- srvyr_select_vars(weights, survey_vars_local)
+    variables <- srvyr_select_vars(variables, survey_vars_local)
+
+    if (is.null(ids)) ids <- ~1
+    out <- survey::svydesign(
+      ids, probs, strata, variables, fpc, survey_vars_local, nest, check_strata, weights, pps
+    )
+    out$variables <- .data
+
+    as_tbl_svy(
+      out,
+      list(ids = ids, probs = probs, strata = strata, fpc = fpc, weights = weights)
+    )
+  }
+
+#' @export
+#' @rdname srvyr-se-deprecated
+#' @inheritParams as_survey_design
 as_survey_design_ <- function(.data, ids = NULL, probs = NULL, strata = NULL,
                               variables = NULL, fpc = NULL, nest = FALSE,
-                              check_strata = !nest,weights = NULL, pps = FALSE,
-                              variance = c("HT", "YG"), uid = NULL) {
-
-
-  # svydesign expects ~0 instead of NULL if no ids are included
-  if (missing(ids) || is.null(ids) || ids == 1 || ids == 0) {
-    ids_call <- ~0
-    ids <- NULL
-  } else {
-    ids_call <- dplyr::select_(.data, .dots = ids)
-  }
-
-  # Databases require uid
-  if (inherits(.data, "tbl_lazy")) {
-    # Databases require uid
-    if (missing(uid) || is.null(uid)) {
-      stop("Database backed surveys require a uid.")
-    } else {
-      uid_names <- get_uid_names(length(uid))
-      .data <- uid_rename(.data, uid, uid_names)
-      attr(.data, "order_var") <- uid_names
-    }
-  }
-
-  out <- survey::svydesign(data = .data,
-                           ids = ids_call,
-                           probs = survey_selector(.data, probs),
-                           strata = survey_selector(.data, strata),
-                           variables = survey_selector(.data, variables),
-                           fpc = survey_selector(.data, fpc),
-                           weights = survey_selector(.data, weights),
-                           nest = nest, check.strata = check_strata, pps = pps,
-                           variance = variance)
-
-  as_tbl_svy(out, list(ids = ids, probs = probs, strata = strata, fpc = fpc,
-                       weights = weights), uid = survey_selector(.data, uid))
+                              check_strata = !nest, weights = NULL, pps = FALSE,
+                              variance = c("HT", "YG")) {
+  as_survey_design(
+    .data,
+    ids = !!n_compat_lazy(ids),
+    probs = !!n_compat_lazy(probs),
+    strata = !!n_compat_lazy(strata),
+    variables = !!n_compat_lazy(variables),
+    fpc = !!n_compat_lazy(fpc),
+    nest = nest,
+    check_strata = check_strata,
+    weights = !!n_compat_lazy(weights),
+    pps = pps,
+    variance = variance
+  )
 }
