@@ -1,12 +1,5 @@
 context("Quick tests for summary stats (ratio / quantile)")
 
-# TODO: switch to improved svyquantile
-if (utils::packageVersion("survey") >= "4.1") {
-  svyq_func <- get("oldsvyquantile", asNamespace("survey"))
-} else {
-  svyq_func <- survey::svyquantile
-}
-
 library(srvyr)
 library(survey)
 source("utilities.R")
@@ -56,42 +49,40 @@ test_that("survey_ratio works for grouped surveys - with vartype=NULL",
 
 ################################################################################
 # survey_quantile
-out_survey <- svyq_func(~api00, dstrata, c(0.5, 0.75), ci = TRUE, df = NULL) %>%
-  {cbind(as.data.frame(.$quantiles),
-         SE(.) %>%
-           as.list() %>%
-           setNames(paste0(names(.), "_se")) %>%
-           as.data.frame(check.names = FALSE))}
+out_survey <- svyquantile(~api00, dstrata, c(0.5, 0.75), df = NULL) %>%
+  {data.frame(
+    api00_q50 = .[[1]]['0.5','quantile'], api00_q75 = .[[1]]['0.75','quantile'],
+    api00_q50_se = .[[1]]['0.5', 'se'], api00_q75_se = .[[1]]['0.75', 'se'],
+    api00_q50_low = .[[1]]['0.5', 'ci.2.5'], api00_q75_low = .[[1]]['0.75', 'ci.2.5'],
+    api00_q50_upp = .[[1]]['0.5', 'ci.97.5'],  api00_q75_upp = .[[1]]['0.75', 'ci.97.5'],
+    api00_q50_var = vcov(.)[1,1], api00_q75_var = vcov(.)[2,2]
+  )} %>%
+  mutate(api00_q50_cv = api00_q50_se/api00_q50,
+         api00_q75_cv = api00_q75_se/api00_q75)
 
 out_srvyr <- dstrata %>%
-  summarise(api00 = survey_quantile(api00, quantiles = c(0.5, 0.75), df = NULL))
+  summarise(api00 = survey_quantile(api00, quantiles = c(0.5, 0.75),
+                                    vartype = c("se", "ci", "var", "cv"), df = NULL))
 
-test_that("survey_quantile works for ungrouped surveys - no ci (with se)",
-          expect_equal(unname(unlist(out_survey)),
-                       unname(unlist(out_srvyr))))
+test_that("survey_quantile works for ungrouped surveys",
+          expect_equal(unname(unlist(out_survey[colnames(out_survey)])),
+                       unname(unlist(out_srvyr[colnames(out_survey)]))))
 
 out_srvyr_vartypeNULL <- dstrata %>%
   summarise(api00 = survey_quantile(api00, quantiles = c(0.5, 0.75),
                                     vartype = NULL))
 
 test_that("survey_quantile works for ungrouped surveys - with vartype=NULL",
-          expect_equal(unname(unlist(select(out_survey, -ends_with("_se")))),
+          expect_equal(unname(unlist(select(out_survey, -matches("_(se|var|cv|low|upp)$")))),
                        unname(unlist(out_srvyr_vartypeNULL))))
 
-out_survey <- svyq_func(~api00, dstrata, c(0.5, 0.75), ci = TRUE, df = NULL)
-
-out_srvyr <- dstrata %>%
-  summarise(api00 = survey_quantile(api00, quantiles = c(0.5, 0.75),
-                                    vartype = "ci", df = NULL))
-
-test_that("survey_quantile works for ungrouped surveys - with ci",
-          expect_equal(c(out_survey$CIs[[1]], out_survey$CIs[[2]]),
-                       c(out_srvyr[["api00_q50_low"]][[1]],
-                         out_srvyr[["api00_q50_upp"]][[1]])))
-
 out_survey <- suppressWarnings(
-  svyby(~api00, ~stype, dstrata, svyq_func,
-        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL))
+  svyby(~api00, ~stype, dstrata, svyquantile,
+        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL,
+        vartype = c("se"))) %>%
+  as.data.frame() %>%
+  rename(api00_q50 = api00.0.5, api00_q75 = api00.0.75,
+         api00_q50_se = se.api00.0.5, api00_q75_se = se.api00.0.75)
 
 out_srvyr <- suppressWarnings(
   dstrata %>%
@@ -100,9 +91,8 @@ out_srvyr <- suppressWarnings(
                                       vartype = "se", df = NULL)))
 
 test_that("survey_quantile works for grouped surveys - with se",
-          expect_equal(c(out_survey$`0.5`[[1]], out_survey[["se.0.5"]][[1]]),
-                       c(out_srvyr[["api00_q50"]][[1]],
-                         out_srvyr[["api00_q50_se"]][[1]])))
+          expect_equal(unlist(out_survey[,colnames(out_survey)]),
+                       unlist(out_srvyr[,colnames(out_survey)])))
 
 out_srvyr_vartypeNULL <- suppressWarnings(
   dstrata %>%
@@ -111,49 +101,67 @@ out_srvyr_vartypeNULL <- suppressWarnings(
                                       vartype = NULL)))
 
 test_that("survey_quantile works for grouped surveys - with vartype=NULL",
-          expect_identical(unname(unlist(select(out_survey, -starts_with("se.")))),
+          expect_identical(unname(unlist(select(out_survey, -ends_with("_se")))),
                            unname(unlist(out_srvyr_vartypeNULL))))
 
 out_survey <- suppressWarnings(
-  svyby(~api00, ~stype + awards, dstrata, svyq_func,
-        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL))
+  svyby(~api00, ~stype + awards, dstrata, svyquantile,
+        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL)) %>%
+  as.data.frame() %>%
+  rename(
+    api00_q50 = api00.0.5, api00_q75 = api00.0.75,
+    api00_q50_se = se.api00.0.5, api00_q75_se = se.api00.0.75
+  ) %>%
+  dplyr::arrange(stype, awards)
 
 out_srvyr <- suppressWarnings(
   dstrata %>%
     group_by(stype, awards) %>%
     summarise(api00 = survey_quantile(api00, quantiles = c(0.5, 0.75),
-                                      vartype = "se", df = NULL)))
+                                      vartype = "se", df = NULL))) %>%
+  ungroup() %>%
+  dplyr::arrange(stype, awards)
 
 test_that(
   "survey_quantile works for grouped surveys - multiple grouping variables",
-  expect_equal(c(out_survey$`0.5`[[1]], out_survey[["se.0.5"]][[1]]),
-               c(out_srvyr[["api00_q50"]][[1]], out_srvyr[["api00_q50_se"]][[1]])))
+  expect_equal(unlist(out_srvyr[,colnames(out_survey)]),
+               unlist(out_survey[,colnames(out_srvyr)])))
 
 ################################################################################
 # survey_median
-out_survey <- svyq_func(~api00, dstrata, c(0.5), ci = TRUE, df = NULL) %>%
-  {cbind(as.data.frame(.$quantiles),
-         SE(.) %>%
-           as.list() %>%
-           setNames(paste0(names(.), "_se")) %>%
-           as.data.frame(check.names = FALSE))}
+out_survey <- svyquantile(~api00, dstrata, c(0.5, 0.75), df = NULL) %>%
+  {data.frame(
+    api00 = .[[1]]['0.5','quantile'],
+    api00_se = .[[1]]['0.5', 'se'],
+    api00_low = .[[1]]['0.5', 'ci.2.5'],
+    api00_upp = .[[1]]['0.5', 'ci.97.5'],
+    api00_var = vcov(.)[1,1]
+  )} %>%
+  mutate(api00_cv = api00_se/api00)
+
+out_srvyr <- dstrata %>%
+  summarise(api00 = survey_median(api00, vartype = c("se", "ci", "var", "cv"), df = NULL))
+
+test_that("survey_median works for ungrouped surveys",
+          expect_equal(unname(unlist(out_survey[colnames(out_survey)])),
+                       unname(unlist(out_srvyr[colnames(out_survey)]))))
 
 out_srvyr <- dstrata %>%
   summarise(api00 = survey_median(api00, df = NULL))
 
 test_that("survey_median works for ungrouped surveys - no ci",
-          expect_equal(unname(unlist(out_survey)),
+          expect_equal(unname(unlist(out_survey[,c("api00", "api00_se")])),
                        unname(unlist(out_srvyr))))
 
 out_srvyr_vartypeNULL <- dstrata %>%
   summarise(api00 = survey_median(api00, vartype = NULL))
 
 test_that("survey_median works for ungrouped surveys - with vartype=NULL",
-          expect_equal(unname(unlist(select(out_survey, -ends_with("_se")))),
+          expect_equal(unname(unlist(select(out_survey, api00))),
                        unname(unlist(out_srvyr_vartypeNULL))))
 
 out_survey <- suppressWarnings(
-  svyby(~api00, ~stype, dstrata, svyq_func,
+  svyby(~api00, ~stype, dstrata, svyquantile,
         quantiles = 0.5, ci = TRUE, df = NULL))
 
 out_srvyr <- suppressWarnings(
@@ -184,7 +192,7 @@ out_srvyr <- dstrata %>%
 
 ratio <- svyratio(~api00, ~api99, dstrata)
 ratio <- confint(ratio, level = 0.9, df = degf(dstrata))
-mdn <- svyq_func(~api00, dstrata, quantile = 0.5, ci = TRUE, alpha = 0.1, df = NULL)
+mdn <- svyquantile(~api00, dstrata, quantile = 0.5, ci = TRUE, alpha = 0.1, df = NULL)
 mdn <- confint(mdn)
 out_survey <- c(ratio[1], ratio[2], mdn[1], mdn[2])
 names(out_survey) <- c("ratio_low", "ratio_upp", "mdn_low", "mdn_upp")
@@ -203,7 +211,7 @@ ratio <- svyby(~api00, ~stype, denominator = ~api99, dstrata, svyratio)
 ratio <- confint(ratio, level = 0.9, df = degf(dstrata))
 
 mdn <- suppressWarnings(
-  svyby(~api00, ~stype, dstrata, svyq_func,
+  svyby(~api00, ~stype, dstrata, svyquantile,
         quantile = 0.5, ci = TRUE, alpha = 0.1, vartype = "ci", df = NULL) %>%
     data.frame() %>%
     select(-api00, -stype))
@@ -270,7 +278,7 @@ out_survey$survey_ratio_upp <- unname(sv_ci[, 2])
 test_that("deff and df work for grouped survey ratio",
           expect_df_equal(out_srvyr, out_survey))
 
-out_survey <- svyq_func(~api99, dstrata, c(0.5), ci = TRUE, df = df_test)
+out_survey <- svyquantile(~api99, dstrata, c(0.5), ci = TRUE, df = df_test)
 
 out_srvyr <- dstrata %>%
   summarise(survey = survey_median(api99, vartype = "ci", df = df_test))
@@ -285,14 +293,14 @@ out_srvyr <- suppressWarnings(
     summarise(survey = survey_median(api99, vartype = "ci", df = df_test)))
 
 temp_survey <- suppressWarnings(
-  svyby(~api99, ~stype, dstrata, svyq_func, quantiles = c(0.5), ci = TRUE,
+  svyby(~api99, ~stype, dstrata, svyquantile, quantiles = c(0.5), ci = TRUE,
         vartype = c("se", "ci"), df = df_test))
 
 out_survey <- temp_survey %>%
   data.frame() %>%
   tibble::as_tibble() %>%
   rename(survey = api99, survey_low = ci_l, survey_upp = ci_u) %>%
-  select(-se)
+  select(-starts_with("se."))
 
 test_that("df works for grouped survey quantile",
           expect_df_equal(out_srvyr, out_survey))
@@ -312,18 +320,18 @@ suppressWarnings(mysvy <- scd %>%
                 combined_weights = FALSE))
 
 results_srvyr <- mysvy %>%
-  summarize(x = survey_median(arrests, interval_type = "probability"))
+  summarize(x = survey_median(arrests, interval_type = "quantile"))
 
-results_survey <- svyq_func(~arrests, mysvy, quantiles = 0.5,
-                              interval_type = "probability")
+results_survey <- svyquantile(~arrests, mysvy, quantiles = 0.5,
+                              interval.type = "quantile")[[1]]
 
-test_that("srvyr allows you to select probability for interval_type of replicate weights",
+test_that("srvyr allows you to select `quantile` for interval_type of replicate weights",
           expect_equal(results_srvyr[[1]], results_survey[[1]]))
 
 results_srvyr <- mysvy %>%
   summarize(x = survey_median(arrests))
 
-results_survey <- svyq_func(~arrests, mysvy, quantiles = 0.5)
+results_survey <- svyquantile(~arrests, mysvy, quantiles = 0.5)[[1]]
 
 test_that("srvyr does the right thing by default for quantiles of replicate surveys",
           expect_equal(results_srvyr[[1]], results_survey[[1]]))
@@ -341,13 +349,13 @@ test_that(
                                           vartype = c("se", "ci"), df = NULL)))
 
     survey <- suppressWarnings(
-      svyby( ~api99, ~awards, dstrata, svyq_func,
+      svyby( ~api99, ~awards, dstrata, svyquantile,
              quantiles = c(0.25, 0.5, 0.75), ci = TRUE, vartype = c("se", "ci"), df = NULL))
 
-    expect_equal(srvyr$api99_q25, survey$`0.25`)
-    expect_equal(srvyr$api99_q25_se, survey$`se.0.25`)
-    expect_equal(srvyr$api99_q25_low, survey$`ci_l.0.25_api99`)
-    expect_equal(srvyr$api99_q25_upp, survey$`ci_u.0.25_api99`)
+    expect_equal(srvyr$api99_q25, survey$`api99.0.25`)
+    expect_equal(srvyr$api99_q25_se, survey$`se.api99.0.25`)
+    expect_equal(srvyr$api99_q25_low, survey$`ci_l.api99.0.25`)
+    expect_equal(srvyr$api99_q25_upp, survey$`ci_u.api99.0.25`)
   }
 )
 
@@ -704,6 +712,21 @@ test_that(
   }
 )
 
+test_that("unweighted allows named arguments",  {
+  data(api, package = "survey")
+  dclus1 <- as_survey_design(apiclus1, id = dnum, weights = pw, fpc = fpc)
+
+  expect_equal(
+    dclus1 %>% summarize(n = unweighted(a = n())),
+    tibble(na = 183)
+  )
+
+  expect_equal(
+    dclus1 %>% summarize(unweighted(a = n())),
+    tibble(a = 183)
+  )
+})
+
 test_that(
   "unweighted works with filtered data in calibrated or PPS designs", {
     data(api, package = "survey")
@@ -770,3 +793,240 @@ test_that(
     expect_equal(t2, t3)
   }
 )
+
+################################################################################
+# survey_old_quantile
+out_survey <- oldsvyquantile(~api00, dstrata, c(0.5, 0.75), ci = TRUE, df = NULL) %>%
+  {cbind(as.data.frame(.$quantiles),
+         SE(.) %>%
+           as.list() %>%
+           setNames(paste0(names(.), "_se")) %>%
+           as.data.frame(check.names = FALSE))}
+
+out_srvyr <- dstrata %>%
+  summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75), df = NULL))
+
+test_that("survey_old_quantile works for ungrouped surveys - no ci (with se)",
+          expect_equal_or_warn(unname(unlist(out_survey)),
+                               unname(unlist(out_srvyr))))
+
+out_srvyr_vartypeNULL <- dstrata %>%
+  summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75),
+                                        vartype = NULL))
+
+test_that("survey_old_quantile works for ungrouped surveys - with vartype=NULL",
+          expect_equal_or_warn(unname(unlist(select(out_survey, -ends_with("_se")))),
+                               unname(unlist(out_srvyr_vartypeNULL))))
+
+out_survey <- oldsvyquantile(~api00, dstrata, c(0.5, 0.75), ci = TRUE, df = NULL)
+
+out_srvyr <- dstrata %>%
+  summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75),
+                                        vartype = "ci", df = NULL))
+
+test_that("survey_old_quantile works for ungrouped surveys - with ci",
+          expect_equal_or_warn(c(out_survey$CIs[[1]], out_survey$CIs[[2]]),
+                               c(out_srvyr[["api00_q50_low"]][[1]],
+                                 out_srvyr[["api00_q50_upp"]][[1]])))
+
+out_survey <- suppressWarnings(
+  svyby(~api00, ~stype, dstrata, oldsvyquantile,
+        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL))
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75),
+                                          vartype = "se", df = NULL)))
+
+test_that("survey_old_quantile works for grouped surveys - with se",
+          expect_equal_or_warn(c(out_survey$`0.5`[[1]], out_survey[["se.0.5"]][[1]]),
+                               c(out_srvyr[["api00_q50"]][[1]],
+                                 out_srvyr[["api00_q50_se"]][[1]])))
+
+out_srvyr_vartypeNULL <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75),
+                                          vartype = NULL)))
+
+test_that("survey_old_quantile works for grouped surveys - with vartype=NULL",
+          expect_identical_or_warn(unname(unlist(select(out_survey, -starts_with("se.")))),
+                                   unname(unlist(out_srvyr_vartypeNULL))))
+
+out_survey <- suppressWarnings(
+  svyby(~api00, ~stype + awards, dstrata, oldsvyquantile,
+        quantiles = c(0.5, 0.75), ci = TRUE, df = NULL))
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype, awards) %>%
+    summarise(api00 = survey_old_quantile(api00, quantiles = c(0.5, 0.75),
+                                          vartype = "se", df = NULL)))
+
+test_that(
+  "survey_old_quantile works for grouped surveys - multiple grouping variables",
+  expect_equal_or_warn(c(out_survey$`0.5`[[1]], out_survey[["se.0.5"]][[1]]),
+                       c(out_srvyr[["api00_q50"]][[1]], out_srvyr[["api00_q50_se"]][[1]])))
+
+################################################################################
+# survey_old_median
+out_survey <- oldsvyquantile(~api00, dstrata, c(0.5), ci = TRUE, df = NULL) %>%
+  {cbind(as.data.frame(.$quantiles),
+         SE(.) %>%
+           as.list() %>%
+           setNames(paste0(names(.), "_se")) %>%
+           as.data.frame(check.names = FALSE))}
+
+out_srvyr <- dstrata %>%
+  summarise(api00 = survey_old_median(api00, df = NULL))
+
+test_that("survey_old_median works for ungrouped surveys - no ci",
+          expect_equal_or_warn(unname(unlist(out_survey)),
+                               unname(unlist(out_srvyr))))
+
+out_srvyr_vartypeNULL <- dstrata %>%
+  summarise(api00 = survey_old_median(api00, vartype = NULL))
+
+test_that("survey_old_median works for ungrouped surveys - with vartype=NULL",
+          expect_equal_or_warn(unname(unlist(select(out_survey, -ends_with("_se")))),
+                               unname(unlist(out_srvyr_vartypeNULL))))
+
+out_survey <- suppressWarnings(
+  svyby(~api00, ~stype, dstrata, oldsvyquantile,
+        quantiles = 0.5, ci = TRUE, df = NULL))
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(api00 = survey_old_median(api00, vartype = "se", df = NULL)))
+
+test_that("survey_old_median works for grouped surveys - with se",
+          expect_equal_or_warn(unname(unlist(out_survey)),
+                               unname(unlist(out_srvyr))))
+
+out_srvyr_vartypeNULL <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(api00 = survey_old_median(api00, vartype = NULL)))
+
+test_that("survey_old_median works for grouped surveys - with vartype=NULL",
+          expect_identical_or_warn(unname(unlist(select(out_survey, -starts_with("se")))),
+                                   unname(unlist(out_srvyr_vartypeNULL))))
+
+################################################################################
+# old_survey_quantile: level parameter in survey_quantile
+out_srvyr <- dstrata %>%
+  summarize(mdn = survey_old_median(api00, vartype = "ci", level = 0.9)) %>%
+  select(-mdn) %>%
+  unlist()
+
+mdn <- oldsvyquantile(~api00, dstrata, quantile = 0.5, ci = TRUE, alpha = 0.1, df = NULL)
+mdn <- confint(mdn)
+out_survey <- c(mdn[1], mdn[2])
+names(out_survey) <- c("mdn_low", "mdn_upp")
+
+test_that("survey_old_median: median with CIs respect level parameter (ungrouped)",
+          expect_df_equal_or_warn(out_srvyr, out_survey))
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarize(mdn = survey_old_median(api00, vartype = "ci", level = 0.9)) %>%
+    select(-mdn, -stype))
+
+mdn <- suppressWarnings(
+  svyby(~api00, ~stype, dstrata, oldsvyquantile,
+        quantile = 0.5, ci = TRUE, alpha = 0.1, vartype = "ci", df = NULL) %>%
+    data.frame() %>%
+    select(-api00, -stype))
+
+out_survey <- mdn
+names(out_survey) <- c("mdn_low", "mdn_upp")
+
+test_that("old_survey_median: median with CIs respect level parameter (grouped)",
+          expect_df_equal_or_warn(out_srvyr, out_survey))
+
+################################################################################
+# survey_old_quantile: deff and df parameters
+
+out_survey <- oldsvyquantile(~api99, dstrata, c(0.5), ci = TRUE, df = df_test)
+
+out_srvyr <- dstrata %>%
+  summarise(survey = survey_old_median(api99, vartype = "ci", df = df_test))
+
+test_that("survey_old_quantile: df works for ungrouped survey quantile",
+          expect_equal_or_warn(confint(out_survey)[c(1, 2)],
+                               c(out_srvyr[["survey_low"]][[1]], out_srvyr[["survey_upp"]][[1]])))
+
+out_srvyr <- suppressWarnings(
+  dstrata %>%
+    group_by(stype) %>%
+    summarise(survey = survey_old_median(api99, vartype = "ci", df = df_test)))
+
+temp_survey <- suppressWarnings(
+  svyby(~api99, ~stype, dstrata, oldsvyquantile, quantiles = c(0.5), ci = TRUE,
+        vartype = c("se", "ci"), df = df_test))
+
+out_survey <- temp_survey %>%
+  data.frame() %>%
+  tibble::as_tibble() %>%
+  rename(survey = api99, survey_low = ci_l, survey_upp = ci_u) %>%
+  select(-se)
+
+test_that("survey_old_quantile: df works for grouped survey quantile",
+          expect_df_equal_or_warn(out_srvyr, out_survey))
+
+################################################################################
+# old_survey_quantile with replicate weights
+data(scd, package = "survey")
+
+scd <- scd %>%
+  mutate(rep1 = 2 * c(1, 0, 1, 0, 1, 0),
+         rep2 = 2 * c(1, 0, 0, 1, 0, 1),
+         rep3 = 2 * c(0, 1, 1, 0, 0, 1),
+         rep4 = 2 * c(0, 1, 0, 1, 1, 0))
+
+suppressWarnings(mysvy <- scd %>%
+                   as_survey_rep(type = "BRR", repweights = starts_with("rep"),
+                                 combined_weights = FALSE))
+
+results_srvyr <- mysvy %>%
+  summarize(x = survey_old_median(arrests, interval_type = "probability"))
+
+results_survey <- oldsvyquantile(~arrests, mysvy, quantiles = 0.5,
+                                 interval_type = "probability")
+
+test_that("survey_old_quantile: srvyr allows you to select probability for interval_type of replicate weights",
+          expect_equal_or_warn(results_srvyr[[1]], results_survey[[1]]))
+
+results_srvyr <- mysvy %>%
+  summarize(x = survey_old_median(arrests))
+
+results_survey <- oldsvyquantile(~arrests, mysvy, quantiles = 0.5)
+
+test_that("survey_old_quantile: srvyr does the right thing by default for quantiles of replicate surveys",
+          expect_equal_or_warn(results_srvyr[[1]], results_survey[[1]]))
+
+test_that(
+  "survey_old_quantile: Can calculate multiple quantiles on grouped data (#38)",
+  {
+    dstrata <- apistrat %>%
+      as_survey_design(strata = stype, weights = pw)
+
+    srvyr <- suppressWarnings(
+      dstrata %>%
+        group_by(awards) %>%
+        summarise(api99 = survey_old_quantile(api99, c(0.25, 0.5, 0.75),
+                                              vartype = c("se", "ci"), df = NULL)))
+
+    survey <- suppressWarnings(
+      svyby( ~api99, ~awards, dstrata, oldsvyquantile,
+             quantiles = c(0.25, 0.5, 0.75), ci = TRUE, vartype = c("se", "ci"), df = NULL))
+
+    expect_equal_or_warn(srvyr$api99_q25, survey$`0.25`)
+    expect_equal_or_warn(srvyr$api99_q25_se, survey$`se.0.25`)
+    expect_equal_or_warn(srvyr$api99_q25_low, survey$`ci_l.0.25_api99`)
+    expect_equal_or_warn(srvyr$api99_q25_upp, survey$`ci_u.0.25_api99`)
+  }
+)
